/* ------------------------------------------------------------------- 
* Header files 
* ------------------------------------------------------------------- */ 
#include "arm_math.h" 
#include "device.h"
#include "FFT.h"

#define	START_COUNT()					tick_before = *pREG_DWT0_CYCCNT;
#define STOP_COUNT()					tick_after = *pREG_DWT0_CYCCNT;
#define TEST_LENGTH_SAMPLES 2048 

/* ------------------------------------------------------------------- 
* Global Functions 
* ------------------------------------------------------------------- */ 
void CallSomeFlashCode(int BlinkCnt);
void DataStoreLoad(bool Store);
void TestFFT(void);

/* ------------------------------------------------------------------- 
* External Input and Output buffer Declarations for FFT Bin Example 
* ------------------------------------------------------------------- */ 
extern float32_t testInput_f32_10khz[TEST_LENGTH_SAMPLES]; 
float32_t testInput_f32_10khz_temp[TEST_LENGTH_SAMPLES]; 
float32_t testOutput[TEST_LENGTH_SAMPLES/2]; 
 
/* ------------------------------------------------------------------ 
* Global variables for FFT Bin Example 
* ------------------------------------------------------------------- */ 
uint32_t fftSize = 1024; 
uint32_t ifftFlag = 0; 
uint32_t doBitReverse = 1; 
arm_status status = ARM_MATH_SUCCESS; 
arm_cfft_radix4_instance_f32 S; 
float32_t maxValue;  
uint32_t refIndex = 213, testIndex = 0;                 // Reference index at which max energy of bin ocuurs // 

/* ------------------------------------------------------------------ 
* Global variables for Test code 
* ------------------------------------------------------------------- */ 
unsigned int TestCnt = 0;
unsigned int tick_before = 0;				// Timer value before counting
unsigned int tick_after = 0;				// Timer value after counting
unsigned int CycleCOUNT[TEST_CNT] = {0};


/* ---------------------------------------------------------------------- 
* Flash based LED blink code 
* ------------------------------------------------------------------- */ 
int main()
{
    /* system initialization with CMSIS API*/
    SystemInit();
        
    /* configures CGU, SPI */
    #ifdef SET_CLOCKS
    ConfigureClocks();
    #endif
    
    /* Configures the flash in XIP mode */
    #ifdef PLACE_FLASH 
      #ifdef XIP_ENABLE
        Set_MemMap_XIP();
      #endif
    #endif
    
    /* Configure cache with or without prefetch enabled */
    #ifndef BYPASS_CACHE
      #ifdef PREFETCH_ENABLE
        CacheEnablePrefetch();
      #endif
    #endif
        
    #ifdef BYPASS_CACHE
    ByPassCache();
    #endif
    
    /*Store Input buffer*/
    DataStoreLoad(true);

    /*Enable Cache counters*/    
    CacheCountersEnable();     
                          
    /*Clear Cache initially for testing*/    
    CacheClear();
                
    /*Call function and measure cycle count*/    
    for(TestCnt = 0; TestCnt < TEST_CNT; TestCnt++)
    {
            /*Test number delimiter*/ 
            printf("\n\n---------------------------------\n");  
            printf("TEST RUN :: %d\n",TestCnt);  
              
            /*Clear Counters*/
            CacheCountersReset();
            
            /*profile count and call our function*/
            START_COUNT()        
            TestFFT();   
            STOP_COUNT()              
              
            /*Read Counters*/
            CacheCountersRead();
            
            /*print out counter values*/
            CacheCountersPrint();
                              
            /*measure count*/
            CycleCOUNT[TestCnt] = tick_after - tick_before;                 
            printf("CycleCOUNT%d = %d\t",TestCnt, CycleCOUNT[TestCnt]);  
            
            /*Test status*/
            if(testIndex !=  refIndex) 
               printf("\n TEST FAIL");
            else printf("\n TEST PASS");
            
            /*Clean up buffers*/
            DataStoreLoad(false);
            
    }
           
    return 0;
}


/*
       Test function that in turns call all CMSIS FFT related functions 
*/
#ifdef PLACE_FLASH
  #pragma location = ".flash_code"
#endif
void TestFFT()
{          
    /* Initialize the CFFT/CIFFT module */  
	status = arm_cfft_radix4_init_f32(&S, fftSize,ifftFlag, doBitReverse); 
	 
	/* Process the data through the CFFT/CIFFT module */ 
	arm_cfft_radix4_f32(&S, testInput_f32_10khz); 	 
	 
	/* Process the data through the Complex Magnitude Module for calculating the magnitude at each bin */ 
	arm_cmplx_mag_f32(testInput_f32_10khz, testOutput, fftSize);  
	 
	/* Calculates maxValue and returns corresponding BIN value */ 
	arm_max_f32(testOutput, fftSize, &maxValue, &testIndex); 
}

/*
       This function simply stores and loads input and output buffers
*/
void DataStoreLoad(bool Store)
{
        int i = 0;
    
        if(Store)
        {
          for(i = 0; i < TEST_LENGTH_SAMPLES; i++) testInput_f32_10khz_temp[i] = testInput_f32_10khz[i];
    
          for(i = 0; i < TEST_LENGTH_SAMPLES/2; i++)testOutput[i] = 0;          
        }
        else
        {
          for(i = 0; i < TEST_LENGTH_SAMPLES; i++) testInput_f32_10khz[i] = testInput_f32_10khz_temp[i];
    
          for(i = 0; i < TEST_LENGTH_SAMPLES/2; i++) testOutput[i] = 0;          
        }

} 