/* ------------------------------------------------------------------- 
* Header files 
* ------------------------------------------------------------------- */ 
#include "device.h"
#include <stdio.h>
#include "system.h"
#include "core_cm4.h"

/* ------------------------------------------------------------------ 
* Global variables
* ------------------------------------------------------------------- */ 
struct CacheCNTREG
{ 
  unsigned int ICodeRefCnt;
  unsigned int DCodeRefCnt; 
  unsigned int ICodeMissCnt;  
  unsigned int DCodeMissCnt;
  unsigned int ICodeFillCnt;
  unsigned int DCodeFillCnt;  
};
struct CacheCNTREG CCNT;
/* ------------------------------------------------------------------- 
* Global Functions 
* ------------------------------------------------------------------- */ 
void CacheCountersEnable(void);
void CacheCountersReset(void);
void CacheCountersRead(void);
void CacheCountersPrint(void);

/* ------------------------------------------------------------------- 
* Cache utility Functions 
* ------------------------------------------------------------------- */ 

/*      
    Enable Cache Counters
*/
void CacheCountersEnable()
{ 
    //enable counter, enable speculative
    *pREG_M4P0_CACHE_CNTCTL = 0x1 | 0x2; 
    __DSB();
      
}
/*      
    Reset Cache Counters
*/
void CacheCountersReset()
{
    //Set RESET bit
    *pREG_M4P0_CACHE_CNTCTL |= 0x4; __DSB();
    
    //wait for RESET bit to be self-cleared
    while(*pREG_M4P0_CACHE_CNTCTL & 0x4) __NOP();    
    __DSB(); 
}

/*
   Read counters
*/
void CacheCountersRead()
{
    //read all counters
    CCNT.ICodeRefCnt  = *pREG_M4P0_CACHE_IREF;
    __DSB();
    CCNT.ICodeMissCnt = *pREG_M4P0_CACHE_IMISS;
    __DSB();
    CCNT.ICodeFillCnt = *pREG_M4P0_CACHE_IFILL;
    __DSB();
  
}
/*
   Print counters
*/
void CacheCountersPrint()
{
    //print ICode counters
    printf("ICodeRefCnt  = %d \n",CCNT.ICodeRefCnt);
    printf("ICodeMissCnt = %d \n",CCNT.ICodeMissCnt);
    printf("ICodeFillCnt = %d \n",CCNT.ICodeFillCnt);
}
