/* ------------------------------------------------------------------- 
* Header files 
* ------------------------------------------------------------------- */ 
#include "device.h"
#include "Memory_placement.h"
/* ------------------------------------------------------------------- 
* Global Data 
* ------------------------------------------------------------------- */ 
unsigned int tick_before = 0;				                                         // Timer value before counting
unsigned int tick_after = 0;				                                         // Timer value after counting
unsigned int CycleCOUNT[2] = 0;
unsigned int TestCnt = 0;
int overhead = 0;
/* ------------------------------------------------------------------- 
* MACROs
* ------------------------------------------------------------------- */ 
#define REG_DWT0_CYCCNT                 0xE0001004                                               //  DWT0 DWT Current PC Sampler Cycle Count Register
#define pREG_DWT0_CYCCNT                ((volatile  uint32_t *) REG_DWT0_CYCCNT)                 //  DWT Current PC Sampler Cycle Count Register 
#define	START_COUNT()					tick_before = *pREG_DWT0_CYCCNT;
#define STOP_COUNT()					tick_after = *pREG_DWT0_CYCCNT;

/* ------------------------------------------------------------------- 
* Global Functions 
* ------------------------------------------------------------------- */ 
void CallPerfAnalysis(void);
void LinearCode(void);
void InitializeDWTCounter(void);

/* ------------------------------------------------------------------- 

* ------------------------------------------------------------------- */ 

void CallPerfAnalysis()
{
  /*we clear cache first*/
  CacheClear();
  InitializeDWTCounter();
  
   START_COUNT()
   STOP_COUNT()
   overhead = tick_after - tick_before;

  /*Call function and measure cycle count*/
    for(TestCnt = 0; TestCnt < 2; TestCnt++)
  {
    
    START_COUNT()   
    LinearCode();      
    STOP_COUNT()
    __ISB();  
      
    CycleCOUNT[TestCnt] = tick_after - tick_before - overhead; 
    printf("\nCycleCOUNT%d = %d\t",TestCnt, CycleCOUNT[TestCnt]);  
 
  }    
    
}

/*
* linear code with 999, 32-bit instructions      
*/
#ifdef PLACE_FLASH
  #pragma location = ".flash_code"
#endif
#ifdef PLACE_ASYNCSRAM
  #pragma location = ".async_code"
#endif
#ifdef PLACE_MEMYCODE
  #pragma location = ".memy_code"
#endif
void LinearCode()
{

  
  asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");         asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");                   
  asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");         asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           
  asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");         asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");
  asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");         asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");
  asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");         asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           
  asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");         asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");        
  asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");         asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           
  asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");         asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           
  asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");         asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           
  asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");                            asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");           asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23"); asm("MOV R5,#23");     
  
  }


void InitializeDWTCounter(void)
{
		   
    *pREG_DWT0_CTRL |= 1; // enable the counter
    __DSB(); 
	*pREG_DWT0_CYCCNT = 0; // reset the counter
	__DSB();
}
